(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     21380,        630]
NotebookOptionsPosition[     19931,        598]
NotebookOutlinePosition[     20342,        614]
CellTagsIndexPosition[     20299,        611]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Created by Marvin Zanke", "Author",
 CellChangeTimes->{{3.820295694318317*^9, 
  3.820295714020083*^9}},ExpressionUUID->"af7e7cd1-4cb2-48b8-a6c4-\
2f3699ae107e"],

Cell[CellGroupData[{

Cell["\<\
Relativistic Coulomb Potential (Perform a Taylor Expansion in Mathematica)\
\>", "Title",
 CellChangeTimes->{{3.820295731258935*^9, 3.820295753565494*^9}, {
  3.820297802110652*^9, 
  3.8202978036484623`*^9}},ExpressionUUID->"a54448c8-256e-4ef5-86fb-\
159aca426668"],

Cell[TextData[{
 "On exercise sheet 12, H.1), we calculated the energy levels of the \
relativistic Coulomb problem. To this end, we introduced Temple\
\[CloseCurlyQuote]s operator, which makes it possible to reduce the \
relativistic Coulomb equation,\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "r"]}], 
         RowBox[{
          FractionBox[
           SuperscriptBox["\[PartialD]", "2"], 
           RowBox[{"\[PartialD]", 
            SuperscriptBox["r", "2"]}]], "r"}]}], "+", 
        RowBox[{
         FractionBox["1", 
          SuperscriptBox["r", "2"]], 
         SuperscriptBox[
          OverscriptBox["L", "\[RightVector]"], "2"]}], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"E", "+", 
           FractionBox["\[Gamma]", "r"]}], ")"}], "2"], "-", 
        RowBox[{
         FractionBox["\[ImaginaryI]\[Gamma]", 
          SuperscriptBox["r", "3"]], 
         RowBox[{"(", 
          RowBox[{
           OverscriptBox["\[Alpha]", "\[RightVector]"], "\[CenterDot]", 
           OverscriptBox["r", "\[RightVector]"]}], ")"}]}], "+", 
        SuperscriptBox["m", "2"]}], ")"}], "\[Psi]"}], "=", "0"}], ","}], 
   TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "eb6a6da2-6f62-45c3-8d2e-e7eb3c005c64"],
 "\nto the form of the non-relativistic problem\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "r"]}], 
         RowBox[{
          FractionBox[
           SuperscriptBox["\[PartialD]", "2"], 
           RowBox[{"\[PartialD]", 
            SuperscriptBox["r", "2"]}]], "r"}]}], "+", 
        FractionBox[
         RowBox[{"l", "(", 
          RowBox[{"l", "+", "1"}], ")"}], 
         SuperscriptBox["r", "2"]], "-", 
        FractionBox[
         RowBox[{"2", "m\[Gamma]"}], "r"], "-", 
        RowBox[{"2", "m", " ", "E"}]}], ")"}], "\[Psi]"}], "=", "0"}], ","}], 
   TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "c1a4488c-cd0d-44d4-a628-83859d6b0e94"],
 "\nwith the identifications ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["m", "~"], "=", "E"}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "c8431734-ea11-4ced-a838-8be49b39f24d"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     OverscriptBox["E", "~"], "=", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", 
        OverscriptBox["m", "~"]}]], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["E", "2"], "-", 
        SuperscriptBox["m", "2"]}], ")"}]}]}], ","}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "d6db23e3-d245-4906-b653-c6fa3070912e"],
 "i.e.\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "r"]}], 
        RowBox[{
         FractionBox[
          SuperscriptBox["\[PartialD]", "2"], 
          RowBox[{"\[PartialD]", 
           SuperscriptBox["r", "2"]}]], "r"}]}], "+", 
       FractionBox[
        RowBox[{
         OverscriptBox["l", "~"], "(", 
         RowBox[{
          OverscriptBox["l", "~"], "+", "1"}], ")"}], 
        SuperscriptBox["r", "2"]], "-", 
       FractionBox[
        RowBox[{"2", 
         OverscriptBox["m", "~"], "\[Gamma]"}], "r"], "-", 
       RowBox[{"2", 
        OverscriptBox["m", "~"], " ", 
        OverscriptBox["E", "~"]}]}], ")"}], "\[Psi]"}], "=", "0."}], 
   TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "cff9b1d7-cca5-46ff-a783-529a277bbdf6"],
 "\nHere, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["l", "~"], "=", 
    TagBox[GridBox[{
       {"\[Piecewise]", GridBox[{
          {
           SubscriptBox["\[Lambda]", "0"], 
           RowBox[{
            RowBox[{
             RowBox[{"for", " ", "\[Lambda]"}], "=", 
             SubscriptBox["\[Lambda]", "0"]}], ","}]},
          {
           RowBox[{
            SubscriptBox["\[Lambda]", "0"], "-", "1"}], 
           RowBox[{
            RowBox[{"for", " ", "\[Lambda]"}], "=", 
            RowBox[{"-", 
             SubscriptBox["\[Lambda]", 
              RowBox[{"0", ","}]]}]}]}
         },
         AllowedDimensions->{2, Automatic},
         Editable->True,
         GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
         GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{1.}}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.84]}, 
             Offset[0.27999999999999997`]}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}},
         Selectable->True]}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{1.}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.35]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}],
     "Piecewise",
     DeleteWithContents->True,
     Editable->False,
     SelectWithContents->True,
     Selectable->False]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "4a987473-a9ca-41af-b397-72fce8b9b850"],
 "\nand ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[Lambda]", "2"], "=", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"j", "+", 
        FractionBox["1", "2"]}], ")"}], "2"], "-", 
     RowBox[{
      SuperscriptBox["\[Gamma]", "2"], "."}]}]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "1c59f643-fc72-4cc9-b917-d9eec122feef"],
 " (For more details, see the exercise.)\nFor the non-relativistic equation, \
we know from Quantum Mechanics 101 that the energy levels are given by\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     OverscriptBox["E", "~"], "=", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        OverscriptBox["m\[Gamma]", "~"], "2"]}], 
      FractionBox["1", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"N", "+", 
          OverscriptBox["l", "~"], "+", "1"}], ")"}], "2"]]}]}], ","}], 
   TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "4ffffdd1-f813-4d5f-aee3-998f7d323bc4"],
 "\nwhich results in\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", "E"}]], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["E", "2"], "-", 
        SuperscriptBox["m", "2"]}], ")"}]}], "=", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        SuperscriptBox["E\[Gamma]", "2"], "2"]}], 
      FractionBox["1", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"N", "+", 
          OverscriptBox["l", "~"], "+", "1"}], ")"}], "2"]]}]}], ","}], 
   TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "88b997a2-d0c9-4e8e-9b1b-38f651f70014"],
 " \t\t\t\t\t\t(\[ImplicitPlus]\[Times])\nwhere the principal quantum number \
is defined as\n",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "=", 
    RowBox[{"N", "+", "1", "+", 
     RowBox[{"j", "\[PlusMinus]", 
      FractionBox["1", "2"]}]}]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "cc9064d4-c60d-4ec1-a3c2-9b507d6e92d3"],
 "\nfor ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Lambda]", "=", 
    RowBox[{"\[PlusMinus]", 
     RowBox[{
      SubscriptBox["\[Lambda]", "0"], "."}]}]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "709c32e4-819b-4450-8b9c-a095fb85d279"],
 " Hence,\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"N", "+", 
     OverscriptBox["l", "~"], "+", "1"}], "=", 
    RowBox[{
     RowBox[{"n", "-", 
      RowBox[{"j", "\[MinusPlus]", 
       FractionBox["1", "2"]}], "+", 
      OverscriptBox["l", "~"]}], "=", 
     RowBox[{"n", "-", "j", "-", 
      FractionBox["1", "2"], "+", 
      SubscriptBox["\[Lambda]", "0."]}]}]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "ec635360-bb8a-476d-b5d6-b6d48f5dc203"],
 "\n(Again, for more details, see the exercise sheet.)\nWe now solve for the \
energy levels ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["E", "nj"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "76734e15-d1f2-4878-91ec-c98dca0fbf10"],
 "."
}], "Text",
 CellChangeTimes->{{3.820295763706955*^9, 3.82029576771633*^9}, {
  3.8202958109955063`*^9, 3.820295831117392*^9}, {3.820295887736123*^9, 
  3.820295958209598*^9}, {3.820296041974595*^9, 3.820296248675349*^9}, {
  3.820296286253729*^9, 3.820296506096766*^9}, {3.8202965427915173`*^9, 
  3.820296903442904*^9}, {3.8202969882283983`*^9, 3.820297031454599*^9}, {
  3.820297154112937*^9, 3.820297215550099*^9}, {3.8202972735301867`*^9, 
  3.820297296233726*^9}, {3.820297774859535*^9, 
  3.820297776953527*^9}},ExpressionUUID->"94c77598-77a0-4833-9200-\
e32d619a5dad"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"We", " ", "define", " ", "c"}], ":=", " ", 
    RowBox[{
     RowBox[{"N", "+", 
      OverscriptBox["l", "~"], "+", "1"}], " ", "=", " ", 
     RowBox[{"n", "-", "j", "-", 
      FractionBox["1", "2"], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "0"], " ", "and", " ", "solve", " ", "the", 
       " ", "above", " ", "equation", " ", 
       RowBox[{"(", "\[Times]", ")"}], " ", "for", " ", 
       RowBox[{"E", "."}]}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox["1", 
         RowBox[{"2", "Enj"}]], 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["Enj", "2"], "-", 
          SuperscriptBox["m", "2"]}], ")"}]}], "\[Equal]", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"-", "Enj"}], "*", 
          SuperscriptBox["\[Gamma]", "2"]}], "2"], 
        FractionBox["1", 
         SuperscriptBox["c", "2"]]}]}], ",", "Enj"}], "]"}], "//", 
    "Simplify"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "We", " ", "take", " ", "the", " ", "positive", " ", "energy", " ", 
      "solution", " ", "and", " ", "simplify", " ", "it", " ", "further", " ",
       "by", " ", "hand"}], ",", " ", 
     RowBox[{"additionaly", " ", "inserting", " ", "c", " ", "and", " ", 
      RowBox[{
       SubscriptBox["\[Lambda]", "0"], "."}]}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"EnjSol", "=", 
    RowBox[{
     RowBox[{
      FractionBox["m", 
       SqrtBox[
        RowBox[{"1", "+", 
         FractionBox[
          SuperscriptBox["\[Gamma]", "2"], 
          SuperscriptBox["c", "2"]]}]]], "/.", 
      RowBox[{"{", 
       RowBox[{"c", "\[Rule]", 
        RowBox[{"n", "-", "j", "-", 
         FractionBox["1", "2"], "+", "\[Lambda]0"}]}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{"\[Lambda]0", "\[Rule]", 
       SqrtBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"j", "+", 
            FractionBox["1", "2"]}], ")"}], "2"], "-", 
         SuperscriptBox["\[Gamma]", "2"]}]]}], "}"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.820258919234466*^9, 3.820259010316456*^9}, {
  3.820259049886203*^9, 3.820259050079022*^9}, {3.8202969059509983`*^9, 
  3.82029712182301*^9}, {3.8202972271411963`*^9, 3.820297254141974*^9}, {
  3.8202973079946413`*^9, 3.820297413080058*^9}, {3.820297787268938*^9, 
  3.820297790298492*^9}},ExpressionUUID->"7022d60a-670a-47a6-9fdc-\
238c8ec4a9dc"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"Enj", "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"c", " ", "m"}], 
        SqrtBox[
         RowBox[{
          SuperscriptBox["c", "2"], "+", 
          SuperscriptBox["\[Gamma]", "2"]}]]]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"Enj", "\[Rule]", 
      FractionBox[
       RowBox[{"c", " ", "m"}], 
       SqrtBox[
        RowBox[{
         SuperscriptBox["c", "2"], "+", 
         SuperscriptBox["\[Gamma]", "2"]}]]]}], "}"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.820258970000662*^9, 3.82025901074607*^9}, 
   3.8202590504745703`*^9, 3.820297039525934*^9, {3.820297108654168*^9, 
   3.82029712250364*^9}, {3.82029736857825*^9, 3.8202974173636293`*^9}},
 CellLabel->"Out[1]=",ExpressionUUID->"50f2ec18-d144-445f-8ec4-98d5a8b7bd25"],

Cell[BoxData[
 FormBox[
  FractionBox["m", 
   SqrtBox[
    RowBox[{
     FractionBox[
      SuperscriptBox["\[Gamma]", "2"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"j", "+", 
              FractionBox["1", "2"]}], ")"}], "2"], "-", 
           SuperscriptBox["\[Gamma]", "2"]}]], "-", "j", "+", "n", "-", 
         FractionBox["1", "2"]}], ")"}], "2"]], "+", "1"}]]], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.820258970000662*^9, 3.82025901074607*^9}, 
   3.8202590504745703`*^9, 3.820297039525934*^9, {3.820297108654168*^9, 
   3.82029712250364*^9}, {3.82029736857825*^9, 3.820297417367215*^9}},
 CellLabel->"Out[2]=",ExpressionUUID->"d84f8b62-c413-4c22-9b57-6e8b81868ad5"]
}, Open  ]],

Cell[TextData[{
 "Since \[Gamma] = Z \[Alpha] ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"\[Alpha]", "=", 
     FractionBox["1", "137"], " "}]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "f8eee17f-fc89-4adf-a5fd-aa8d22fffe63"],
 "being the fine-structure constant), we can for small values of Z expand the \
energy levels ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["E", "nj"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "ed71bd64-7b17-4cb4-8342-53b5943f6928"],
 " in powers of \[Gamma]. The command for this in Mathematica is \
\[OpenCurlyDoubleQuote]Series[...]\[CloseCurlyDoubleQuote], as used below."
}], "Text",
 CellChangeTimes->{{3.8202974300429296`*^9, 3.820297481493207*^9}, {
  3.820297749445095*^9, 
  3.820297766136447*^9}},ExpressionUUID->"96764219-7f82-4e53-ba7e-\
94967130dabf"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "We", " ", "perform", " ", "a", " ", "taylor", " ", "expansion", " ", 
     "around", " ", "\[Gamma]"}], "=", 
    RowBox[{
    "0", " ", "up", " ", "to", " ", "and", " ", "including", " ", "order", 
     " ", "O", 
     RowBox[{
      RowBox[{"(", 
       SuperscriptBox["\[Gamma]", "4"], ")"}], "."}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"EnjSolExpanded", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Series", "[", 
      RowBox[{"EnjSol", ",", 
       RowBox[{"{", 
        RowBox[{"\[Gamma]", ",", "0", ",", "4"}], "}"}]}], "]"}], "//", 
     "PowerExpand"}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.820259137882102*^9, 3.820259170056891*^9}, {
  3.820259212211175*^9, 3.820259265287743*^9}, {3.8202593013321047`*^9, 
  3.820259302869053*^9}, {3.8202974215324163`*^9, 3.8202974279763203`*^9}, {
  3.8202974829894447`*^9, 3.8202975555667667`*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"f1071bf9-90a0-473b-8b9d-387bbfe3f0c0"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"m", "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[Gamma]", "2"], " ", "m"}], 
     RowBox[{"2", " ", 
      SuperscriptBox["n", "2"]}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[Gamma]", "4"], " ", "m", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"6", " ", "j"}], "-", 
        RowBox[{"8", " ", "n"}], "+", "3"}], ")"}]}], 
     RowBox[{"8", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "j"}], "+", "1"}], ")"}], " ", 
      SuperscriptBox["n", "4"]}]], "+", 
    InterpretationBox[
     RowBox[{"O", "(", 
      SuperscriptBox["\[Gamma]", "5"], ")"}],
     SeriesData[$CellContext`\[Gamma], 0, {}, 0, 5, 1],
     Editable->False]}],
   SeriesData[$CellContext`\[Gamma], 
    0, {$CellContext`m, 0, Rational[-1, 2] $CellContext`m $CellContext`n^(-2),
      0, Rational[1, 8] (1 + 2 $CellContext`j)^(-1) $CellContext`m (3 + 
      6 $CellContext`j - 8 $CellContext`n) $CellContext`n^(-4)}, 0, 5, 1],
   Editable->False], TraditionalForm]], "Output",
 CellChangeTimes->{{3.820259247309618*^9, 3.820259265690858*^9}, 
   3.820259303402998*^9, {3.820297541597868*^9, 3.820297557467402*^9}},
 CellLabel->"Out[6]=",ExpressionUUID->"42696ee8-d189-4c02-97e8-fa7bbf93d4ed"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "We", " ", "check", " ", "whether", " ", "this", " ", "is", " ", 
    "equivalent", " ", "to", " ", "the", " ", "expansion", " ", "provided", 
    " ", "on", " ", "the", " ", "proposed", " ", 
    RowBox[{"solution", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"EnjSolExpanded", "-", 
    RowBox[{"(", 
     RowBox[{"m", "-", 
      FractionBox[
       RowBox[{"m", " ", 
        SuperscriptBox["\[Gamma]", "2"]}], 
       RowBox[{"2", 
        SuperscriptBox["n", "2"]}]], "-", 
      RowBox[{
       FractionBox[
        RowBox[{"m", " ", 
         SuperscriptBox["\[Gamma]", "4"]}], 
        RowBox[{"2", 
         SuperscriptBox["n", "4"]}]], 
       RowBox[{"(", 
        RowBox[{
         FractionBox["n", 
          RowBox[{"j", "+", 
           FractionBox["1", "2"]}]], "-", 
         FractionBox["3", "4"]}], ")"}]}]}], 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"+", "O"}], 
       RowBox[{"(", 
        SuperscriptBox["\[Gamma]", "5"], ")"}]}], "*)"}], ")"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Indeed", ",", " ", 
     RowBox[{
     "except", " ", "for", " ", "terms", " ", "of", " ", "higher", " ", 
      "orders", " ", "O", 
      RowBox[{"(", 
       SuperscriptBox["\[Gamma]", "5"], ")"}]}], ",", " ", 
     RowBox[{
     "we", " ", "find", " ", "that", " ", "we", " ", "obtained", " ", "the", 
      " ", "desired", " ", 
      RowBox[{"result", "."}]}]}], " ", "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.820297562620542*^9, 3.820297736985927*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"726e8adb-9cec-4d96-9b95-5092e555ccac"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"O", "(", 
    SuperscriptBox["\[Gamma]", "5"], ")"}],
   SeriesData[$CellContext`\[Gamma], 0, {}, 5, 5, 1],
   Editable->False], TraditionalForm]], "Output",
 CellChangeTimes->{{3.820297665423139*^9, 3.820297682712776*^9}, {
  3.820297716132139*^9, 3.820297739160829*^9}},
 CellLabel->"Out[11]=",ExpressionUUID->"0b958ae3-0dd5-4742-8c73-65461b3827a9"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{808, 615},
WindowMargins->{{-862, Automatic}, {-71, Automatic}},
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->FrontEnd`FileName[{"Report"}, "StandardReport.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 167, 3, 40, "Author",ExpressionUUID->"af7e7cd1-4cb2-48b8-a6c4-2f3699ae107e"],
Cell[CellGroupData[{
Cell[750, 27, 276, 6, 159, "Title",ExpressionUUID->"a54448c8-256e-4ef5-86fb-159aca426668"],
Cell[1029, 35, 9155, 279, 553, "Text",ExpressionUUID->"94c77598-77a0-4833-9200-e32d619a5dad"],
Cell[CellGroupData[{
Cell[10209, 318, 2633, 72, 242, "Input",ExpressionUUID->"7022d60a-670a-47a6-9fdc-238c8ec4a9dc"],
Cell[12845, 392, 877, 25, 64, "Output",ExpressionUUID->"50f2ec18-d144-445f-8ec4-98d5a8b7bd25"],
Cell[13725, 419, 820, 22, 98, "Output",ExpressionUUID->"d84f8b62-c413-4c22-9b57-6e8b81868ad5"]
}, Open  ]],
Cell[14560, 444, 865, 22, 61, "Text",ExpressionUUID->"96764219-7f82-4e53-ba7e-94967130dabf"],
Cell[CellGroupData[{
Cell[15450, 470, 1037, 26, 65, "Input",ExpressionUUID->"f1071bf9-90a0-473b-8b9d-387bbfe3f0c0"],
Cell[16490, 498, 1294, 33, 65, "Output",ExpressionUUID->"42696ee8-d189-4c02-97e8-fa7bbf93d4ed"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17821, 536, 1671, 47, 165, "Input",ExpressionUUID->"726e8adb-9cec-4d96-9b95-5092e555ccac"],
Cell[19495, 585, 408, 9, 47, "Output",ExpressionUUID->"0b958ae3-0dd5-4742-8c73-65461b3827a9"]
}, Open  ]]
}, Open  ]]
}
]
*)

